changeset 106876:ad7558737bc7

Fix typos in docstrings.
author Juanma Barranquero <lekktu@gmail.com>
date Sun, 17 Jan 2010 03:25:53 +0100
parents 81da60e75606
children c29352449572
files doc/lispref/ChangeLog doc/lispref/two.el lisp/ChangeLog lisp/cedet/semantic.el lisp/files.el lisp/gnus/ChangeLog lisp/gnus/nnmairix.el lisp/textmodes/artist.el
diffstat 8 files changed, 40 insertions(+), 22 deletions(-) [+]
line wrap: on
line diff
--- a/doc/lispref/ChangeLog	Sun Jan 17 03:24:22 2010 +0100
+++ b/doc/lispref/ChangeLog	Sun Jan 17 03:25:53 2010 +0100
@@ -1,3 +1,7 @@
+2010-01-17  Juanma Barranquero  <lekktu@gmail.com>
+
+	* two.el (volume-header-toc-markup): Fix typos in docstring.
+
 2010-01-04  Stefan Monnier  <monnier@iro.umontreal.ca>
 
 	Avoid dubious uses of save-excursions.
--- a/doc/lispref/two.el	Sun Jan 17 03:24:22 2010 +0100
+++ b/doc/lispref/two.el	Sun Jan 17 03:25:53 2010 +0100
@@ -54,8 +54,8 @@
 
 (defun volume-header-toc-markup ()
   "Insert Volume I and Volume II text into .toc file.
-NOTE: this auxilary function is file specific.
-This is for the *Elisp Ref Manual*"
+NOTE: this auxiliary function is file specific.
+This is for the *Elisp Ref Manual*."
   (interactive)
   (goto-char (point-min))
   (insert "\\unnumbchapentry {Volume 1}{}\n\\unnumbchapentry {}{}\n")
--- a/lisp/ChangeLog	Sun Jan 17 03:24:22 2010 +0100
+++ b/lisp/ChangeLog	Sun Jan 17 03:25:53 2010 +0100
@@ -1,3 +1,12 @@
+2010-01-17  Juanma Barranquero  <lekktu@gmail.com>
+
+	* cedet/semantic.el (semantic-mode):
+	* files.el (minibuffer-with-setup-hook):
+	* textmodes/artist.el (artist-mt, artist-key-undraw-continously)
+	(artist-key-draw-continously, artist-key-do-continously-continously)
+	(artist-key-set-point-continously, artist-mouse-draw-continously):
+	Fix typos in docstrings.
+
 2010-01-16  Lennart Borgman  <lennart.borgman@gmail.com>
 
 	* nxml/nxml-mode.el (nxml-extend-after-change-region): Never
--- a/lisp/files.el	Sun Jan 17 03:24:22 2010 +0100
+++ b/lisp/files.el	Sun Jan 17 03:25:53 2010 +0100
@@ -1289,7 +1289,7 @@
 Recursive uses of the minibuffer are unaffected (FUN is not
 called additional times).
 
-This macro actually adds an auxilliary function that calls FUN,
+This macro actually adds an auxiliary function that calls FUN,
 rather than FUN itself, to `minibuffer-setup-hook'."
   (declare (indent 1) (debug t))
   (let ((hook (make-symbol "setup-hook")))
--- a/lisp/gnus/ChangeLog	Sun Jan 17 03:24:22 2010 +0100
+++ b/lisp/gnus/ChangeLog	Sun Jan 17 03:25:53 2010 +0100
@@ -1,3 +1,8 @@
+2010-01-17  Juanma Barranquero  <lekktu@gmail.com>
+
+	* nnmairix.el (nnmairix-group-delete-recreate-this-group):
+	Fix typo in docstring.
+
 2010-01-08  Jason Rumney  <jasonr@gnu.org>
 
 	* sieve-manage.el (sieve-manage-parse-capability-1): Loosely match OK
--- a/lisp/gnus/nnmairix.el	Sun Jan 17 03:24:22 2010 +0100
+++ b/lisp/gnus/nnmairix.el	Sun Jan 17 03:25:53 2010 +0100
@@ -1104,7 +1104,7 @@
 
 (defun nnmairix-group-delete-recreate-this-group ()
   "Deletes and recreates group on the back end.
-You can use this function on nnmairix groups which continously
+You can use this function on nnmairix groups which continuously
 show wrong article counts."
   (interactive)
   (let* ((group (gnus-group-group-name))
--- a/lisp/cedet/semantic.el	Sun Jan 17 03:24:22 2010 +0100
+++ b/lisp/cedet/semantic.el	Sun Jan 17 03:25:53 2010 +0100
@@ -1014,7 +1014,7 @@
 
 ;; The `semantic-mode' command, in conjuction with the
 ;; `semantic-default-submodes' variable, toggles Semantic's various
 ;; auxilliary minor modes.
 
 (defvar semantic-load-system-cache-loaded nil
   "Non nil when the Semantic system caches have been loaded.
@@ -1057,7 +1057,7 @@
 
 In Semantic mode, Emacs parses the buffers you visit for their
 semantic content.  This information is used by a variety of
-auxilliary minor modes, listed in `semantic-default-submodes';
+auxiliary minor modes, listed in `semantic-default-submodes';
 all the minor modes in this list are also enabled when you enable
 Semantic mode.
 
@@ -1067,7 +1067,7 @@
   (if semantic-mode
       ;; Turn on Semantic mode
       (progn
 	;; Enable all the global auxilliary minor modes in
 	;; `semantic-submode-list'.
 	(dolist (mode semantic-submode-list)
 	  (if (memq mode semantic-default-submodes)
@@ -1014,7 +1014,7 @@
 ;; The `semantic-mode' command, in conjuction with the
 ;; `semantic-default-submodes' variable, toggles Semantic's various
-;; auxilliary minor modes.
+;; auxiliary minor modes.
 
 (defvar semantic-load-system-cache-loaded nil
@@ -1067,7 +1067,7 @@
       ;; Turn on Semantic mode
       (progn
-	;; Enable all the global auxilliary minor modes in
+	;; Enable all the global auxiliary minor modes in
 	;; `semantic-submode-list'.
 	(dolist (mode semantic-submode-list)
--- a/lisp/textmodes/artist.el	Sun Jan 17 03:24:22 2010 +0100
+++ b/lisp/textmodes/artist.el	Sun Jan 17 03:25:53 2010 +0100
@@ -870,7 +870,7 @@
   is done.  Arguments and return values for this funcion are
   described below.
 DRAW-HOW defines the kind of shape.  The kinds of shapes are:
-  `artist-do-continously'  -- Do drawing operation continously,
+  `artist-do-continously'  -- Do drawing operation continuously,
                               as long as the mouse button is held down.
   `artist-do-poly'         -- Do drawing operation many times.
   1                        -- Do drawing operation only once.
@@ -3879,8 +3879,8 @@
 ;;
 
 (defun artist-key-undraw-continously (x y)
-  "Undraw current continous shape with point at X, Y."
-  ;; No undraw-info for continous shapes
+  "Undraw current continuous shape with point at X, Y."
+  ;; No undraw-info for continuous shapes
   nil)
 
 (defun artist-key-undraw-poly (x y)
@@ -3937,7 +3937,7 @@
 ;; user has released the button, so the timer will always be cancelled
 ;; at that point.
 (defun artist-key-draw-continously (x y)
-  "Draw current continous shape at X,Y."
+  "Draw current continuous shape at X,Y."
   (let ((draw-fn   (artist-go-get-draw-fn-from-symbol artist-curr-go)))
     (setq artist-key-shape (artist-funcall draw-fn x y))))
 
@@ -4018,7 +4018,7 @@
 ;;
 
 (defun artist-key-do-continously-continously (x y)
-  "Update current continous shape at X,Y."
+  "Update current continuous shape at X,Y."
   (let ((draw-fn   (artist-go-get-draw-fn-from-symbol artist-curr-go)))
     (artist-funcall draw-fn x y)))
 
@@ -4045,7 +4045,7 @@
 
 (defun artist-key-do-continously-1point (x y)
   "Update current 1-point shape at X,Y."
   ;; Nothing to do continously for operations
   ;; where we have only one input point
   nil)
 
@@ -4094,8 +4094,8 @@
 
 
 (defun artist-key-set-point-continously (x y)
-  "Set point for current continous shape at X,Y."
-  ;; Maybe set arrow-points for continous shapes
+  "Set point for current continuous shape at X,Y."
+  ;; Maybe set arrow-points for continuous shapes
   (let ((arrow-pred   (artist-go-get-arrow-pred-from-symbol artist-curr-go))
 	(arrow-set-fn (artist-go-get-arrow-set-fn-from-symbol artist-curr-go))
 	(init-fn      (artist-go-get-init-fn-from-symbol artist-curr-go))
@@ -4914,7 +4914,7 @@
 
 (defun artist-mouse-draw-continously (ev)
   "Generic function for shapes that require 1 point as input.
-Operation is done continously while the mouse button is hold down.
+Operation is done continuously while the mouse button is hold down.
 The event, EV, is the mouse event."
   (let* ((unshifted    (artist-go-get-symbol-shift artist-curr-go nil))
 	 (shifted      (artist-go-get-symbol-shift artist-curr-go t))
@@ -5395,8 +5395,8 @@
 ;; 1.   If your new drawing mode falls into one of the following
 ;;      categories, goto point 2, otherwise goto point 3.
 ;;
 ;;         - Modes where the shapes are drawn continously, as long as
 ;;           the mouse button is held down (continous modes).
 ;;           Example: the erase-char mode, the pen and pen-line modes.
 ;;
 ;;         - Modes where the shape is made up of from 2 points to an
@@ -5408,7 +5408,7 @@
 ;;           Example: lines, rectangles
 ;;
 ;;         - Modes where the shape is made up of 1 point (1-point
 ;;           modes). This mode differs from the continous modes in
 ;;           that the shape is drawn only once when the mouse button
 ;;           is pressed.
 ;;           Examples: paste, a flood-fill, vaporize modes
@@ -5426,7 +5426,7 @@
 ;;    For each of the cases below, the arguments given to the init-fn,
 ;;    prep-fill-fn, arrow-set-fn and exit-fn are stated.
 ;;
 ;;    If your mode matches the continous mode or the 1-point mode:
 ;;
 ;;      a. Create a draw-function that draws your shape. Your function
 ;;         must take x and y as arguments. The return value is not
@@ -5538,8 +5538,8 @@
 ;;         - artist-key-set-point-xxx for setting a point in the
 ;;           mode, to be called from `artist-key-set-point-common'.
 ;;
 ;;         - artist-key-do-continously-xxx to be called from
 ;;           `artist-key-do-continously-common' whenever the user
 ;;           moves around.
 ;;
 ;;         As for the artist-mouse-draw-xxx, these two functions must
@@ -4045,7 +4045,7 @@
 (defun artist-key-do-continously-1point (x y)
   "Update current 1-point shape at X,Y."
-  ;; Nothing to do continously for operations
+  ;; Nothing to do continuously for operations
   ;; where we have only one input point
   nil)
@@ -5395,8 +5395,8 @@
 ;;      categories, goto point 2, otherwise goto point 3.
 ;;
-;;         - Modes where the shapes are drawn continously, as long as
-;;           the mouse button is held down (continous modes).
+;;         - Modes where the shapes are drawn continuously, as long as
+;;           the mouse button is held down (continuous modes).
 ;;           Example: the erase-char mode, the pen and pen-line modes.
 ;;
@@ -5408,7 +5408,7 @@
 ;;
 ;;         - Modes where the shape is made up of 1 point (1-point
-;;           modes). This mode differs from the continous modes in
+;;           modes). This mode differs from the continuous modes in
 ;;           that the shape is drawn only once when the mouse button
 ;;           is pressed.
@@ -5426,7 +5426,7 @@
 ;;    prep-fill-fn, arrow-set-fn and exit-fn are stated.
 ;;
-;;    If your mode matches the continous mode or the 1-point mode:
+;;    If your mode matches the continuous mode or the 1-point mode:
 ;;
 ;;      a. Create a draw-function that draws your shape. Your function
@@ -5538,8 +5538,8 @@
 ;;           mode, to be called from `artist-key-set-point-common'.
 ;;
-;;         - artist-key-do-continously-xxx to be called from
-;;           `artist-key-do-continously-common' whenever the user
+;;         - artist-key-do-continuously-xxx to be called from
+;;           `artist-key-do-continuously-common' whenever the user
 ;;           moves around.
 ;;